<TS language="ms" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Create a new address</source>
        <translation>Cipta alamat baru</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Baru</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Salin alamat terpilih ke dalam sistem papan klip</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Salin</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>&amp;Tutup</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Padam alamat semasa yang dipilih dari senaraiyang dipilih dari senarai</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation>Masukkan alamat atau label untuk carian
</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>
Alihkan fail data ke dalam tab semasa</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Padam</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Pilih alamat untuk hantar koin kepada</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Pilih alamat untuk menerima koin dengan</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>&amp;Pilih</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>alamat-alamat penghantaran</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>alamat-alamat penerimaan</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Ini adalah alamat Bitcoin anda untuk pembayaran. Periksa jumlah dan alamat penerima sebelum membuat penghantaran koin sentiasa.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Salin &amp; Label</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Eskport Senarai Alamat</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Fail dibahagi oleh koma(*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Mengeksport Gagal</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Terdapat ralat semasa cubaan menyimpan senarai alamat kepada %1. Sila cuba lagi.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tiada label)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Dialog frasa laluan</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>memasukkan frasa laluan</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Frasa laluan baru</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Ulangi frasa laluan baru</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Dompet encrypt</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>Operasi ini perlukan frasa laluan dompet anda untuk membuka kunci dompet.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Membuka kunci dompet</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>Operasi ini memerlukan frasa laluan dompet anda untuk menyahsulit dompet.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Menyahsulit dompet</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Menukar frasa laluan</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Mengesahkan enkripsi dompet</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>Amaran: Jika anda enkripkan dompet anda dan hilangkan frasa laluan, anda akan &lt;b&gt;ANDA AKAN HILANGKAN SEMUA BITCOIN ANDA&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Anda pasti untuk membuat enkripsi dompet anda?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Dompet dienkripsi</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Memasukkan frasa laluan baru kepada dompet.&lt;br/&gt;Sila mengunakkan frasa laluan yang&lt;b&gt;mengandungi 10 atau lebih aksara rawak&lt;/b&gt;,ataupun&lt;b&gt;lapan atau lebih perkataan.&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation>Memasukkan frasa laluan lama dan frasa laluan baru untuk.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>PENTING: Apa-apa sandaran yang anda buat sebelum ini untuk fail dompet anda hendaklah digantikan dengan fail dompet enkripsi yang dijana baru. Untuk sebab-sebab keselamatan , sandaran fail dompet yang belum dibuat enkripsi sebelum ini akan menjadi tidak berguna secepat anda mula guna dompet enkripsi baru.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Enkripsi dompet gagal</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Enkripsi dompet gagal kerana ralat dalaman. Dompet anda tidak dienkripkan.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Frasa laluan yang dibekalkan tidak sepadan.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Pembukaan kunci dompet gagal</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>Frasa laluan dimasukki untuk dekripsi dompet adalah tidak betul.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Dekripsi dompet gagal</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Frasa laluan dompet berjaya ditukar.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>Amaran: Kunci Caps Lock buka!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>Banned Until</source>
        <translation>Diharamkan sehingga</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Tandatangan &amp; mesej...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Penyegerakan dengan rangkaian...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Gambaran Keseluruhan</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Tunjuk gambaran keseluruhan umum dompet</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksi</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Menyemak imbas sejarah transaksi</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Keluar</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Berhenti aplikasi</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Mengenai%1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Menunjuk informasi mengenai%1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Mengenai &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Menunjuk informasi megenai Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>Pilihan</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Mengubah suai pilihan konfigurasi untuk %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Enkripsi Dompet</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Dompet Sandaran...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Menukar frasa-laluan</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Buka &amp;URI...</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>dompet</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation>Aktiviti rangkaian dilumpuhkan</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)...</source>
        <translation>Penyelarasn tajuk (%1%)...</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Reindexi blok pada cakera...</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation>Menghantar koin kepada alamat Bitcoin</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Wallet sandaran ke lokasi lain</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Tukar kata laluan untuk dompet disulitkan</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>sahkan mesej</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>hantar</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>terima</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;tunjuk/sembunyi</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>tunjuk atau sembunyi tetingkap utama</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>sulitkan kata laluan milik peribadi anda</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation>sahkan mesej bersama alamat bitcoin anda untuk menunjukkan alamat ini anda punya</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation>Sahkan mesej untuk memastikan mereka telah ditandatangani dengan alamat Bitcoin yang ditentukan</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>fail</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>tetapan</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>tolong</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Bar alat tab
</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation>Request payments (generates QR codes and bitcoin: URIs)
</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Tunjukkan senarai alamat dan label yang digunakan
</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Indexi blok pada cakera...</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation><numerusform>Processed %n blocks of transaction history.</numerusform></translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Amaran</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Notis</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Terkini</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation>buka debug dan konsol diagnostik</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Alamat koin penghantaran</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Alamat penerima</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation>Buka Wallet</translation>
    </message>
    <message>
        <source>Close Wallet...</source>
        <translation>Tutup Wallet...</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation>Tutup Wallet</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Amount:</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Amount</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Salin &amp;Label</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tiada label)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation>dompet</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation>Dompet encrypt</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>Alamat</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>About %1</source>
        <translation type="unfinished">Mengenai%1</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of free space available</source>
        <translation><numerusform>%n GB of free space available</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation><numerusform>(of %n GB needed)</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation><numerusform>(%n GB needed for full chain)</numerusform></translation>
    </message>
</context>
<context>
    <name>NetWatchLogModel</name>
    <message>
        <source>Address</source>
        <comment>NetWatch: Address header</comment>
        <translation>Alamat</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>default wallet</source>
        <translation>dompet lalai
</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation>Buka Wallet</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;...</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation>Buka sedang Wallet &lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">&amp;dompet</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Close</source>
        <translation type="unfinished">Tutup</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Amount</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n seconds</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minutes</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation><numerusform>%n hours</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation><numerusform>%n days</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n weeks</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation><numerusform>%n years</numerusform></translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Notis</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">dompet </translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer</extracomment>
        <translation>&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Aktiviti rangkaian dilumpuhkan</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Amount:</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Salin &amp;Label</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Alamat:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Amount:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation>dompet</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>&amp;Salin Alamat</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>(no label)</source>
        <translation>(tiada label)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Amount:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation type="unfinished">Pilih...</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Baki</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">hantar</translation>
    </message>
    <message>
        <source>Cr&amp;eate Unsigned</source>
        <translation type="unfinished">&amp;Create Unsigned</translation>
    </message>
    <message>
        <source>Create Unsigned</source>
        <translation type="unfinished">Create Unsigned</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished">hantar</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation><numerusform>Estimated to begin confirmation within %n blocks.</numerusform></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tiada label)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">&amp;Amount:</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation><numerusform>Open for %n more blocks</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation><numerusform>matures in %n more blocks</numerusform></translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transaksi</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Amount</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message numerus="yes">
        <source>Open for %n more block(s)</source>
        <translation><numerusform>Open for %n more blocks</numerusform></translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(tiada label)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation>&amp;Salin Aamat</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation>Salin &amp;Label</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Fail dibahagi oleh koma(*.csv)</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Alamat</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Mengeksport Gagal</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation>Tutup Wallet</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>default wallet</source>
        <translation>dompet lalai
</translation>
    </message>
</context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Eksport</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>
Alihkan fail data ke dalam tab semasa</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Dompet Sandaran</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Error</source>
        <translation>Ralat</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Sedang baca wallet...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Baca Selesai</translation>
    </message>
</context>
</TS>
